Skip to contents

A four-variable within-person system with autoregressive coefficients between .30 and .45, a few cross-lagged effects, an innovation covariance with a sparse contemporaneous network, and stationary variances equal to one.

Usage

default_params()

Value

A list with Phi (4 x 4 lagged coefficients), Psi

(innovation covariance, scaled so that the stationary variances equal one), mu (population means), Sigma_mu (between-person covariance of the person means) and vars, the variable names

c("NegA", "PosA", "Stress", "Fatigue").

Examples

p <- default_params()
p$Phi
#>          NegA  PosA Stress Fatigue
#> NegA     0.40  0.00   0.15     0.0
#> PosA    -0.10  0.35   0.00     0.0
#> Stress   0.15  0.00   0.45     0.1
#> Fatigue  0.00 -0.10   0.00     0.3
# contemporaneous network: NegA--PosA -.30, NegA--Stress .30, Stress--Fatigue .20
round(partial_cors(p$Psi), 2)
#>         NegA PosA Stress Fatigue
#> NegA     1.0 -0.3    0.3     0.0
#> PosA    -0.3  1.0    0.0     0.0
#> Stress   0.3  0.0    1.0     0.2
#> Fatigue  0.0  0.0    0.2     1.0